@@ -18,13 +18,12 @@ from typing import Any, Dict, List, Type, overload
 
 from botocore.client import ClientMeta
 
-from mypy_boto3_emr_containers.paginator import (
+from .literals import EndpointStateType, JobRunStateType, VirtualClusterStateType
+from .paginator import (
     ListJobRunsPaginator,
     ListManagedEndpointsPaginator,
     ListVirtualClustersPaginator,
 )
-
-from .literals import EndpointState, JobRunState, VirtualClusterState
 from .type_defs import (
     CancelJobRunResponseTypeDef,
     ConfigurationOverridesTypeDef,
@@ -70,7 +69,7 @@ class Exceptions:
 
 class EMRContainersClient:
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/emr-containers.html#EMRContainers.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/emr-containers.html#EMRContainers.Client)
     [Show boto3-stubs documentation](./client.md)
     """
 
@@ -79,14 +78,14 @@ class EMRContainersClient:
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/emr-containers.html#EMRContainers.Client.can_paginate)
-        [Show boto3-stubs documentation](./client.md#can-paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/emr-containers.html#EMRContainers.Client.can_paginate)
+        [Show boto3-stubs documentation](./client.md#can_paginate)
         """
 
     def cancel_job_run(self, id: str, virtualClusterId: str) -> CancelJobRunResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/emr-containers.html#EMRContainers.Client.cancel_job_run)
-        [Show boto3-stubs documentation](./client.md#cancel-job-run)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/emr-containers.html#EMRContainers.Client.cancel_job_run)
+        [Show boto3-stubs documentation](./client.md#cancel_job_run)
         """
 
     def create_managed_endpoint(
@@ -102,8 +101,8 @@ class EMRContainersClient:
         tags: Dict[str, str] = None,
     ) -> CreateManagedEndpointResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/emr-containers.html#EMRContainers.Client.create_managed_endpoint)
-        [Show boto3-stubs documentation](./client.md#create-managed-endpoint)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/emr-containers.html#EMRContainers.Client.create_managed_endpoint)
+        [Show boto3-stubs documentation](./client.md#create_managed_endpoint)
         """
 
     def create_virtual_cluster(
@@ -114,42 +113,42 @@ class EMRContainersClient:
         tags: Dict[str, str] = None,
     ) -> CreateVirtualClusterResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/emr-containers.html#EMRContainers.Client.create_virtual_cluster)
-        [Show boto3-stubs documentation](./client.md#create-virtual-cluster)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/emr-containers.html#EMRContainers.Client.create_virtual_cluster)
+        [Show boto3-stubs documentation](./client.md#create_virtual_cluster)
         """
 
     def delete_managed_endpoint(
         self, id: str, virtualClusterId: str
     ) -> DeleteManagedEndpointResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/emr-containers.html#EMRContainers.Client.delete_managed_endpoint)
-        [Show boto3-stubs documentation](./client.md#delete-managed-endpoint)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/emr-containers.html#EMRContainers.Client.delete_managed_endpoint)
+        [Show boto3-stubs documentation](./client.md#delete_managed_endpoint)
         """
 
     def delete_virtual_cluster(self, id: str) -> DeleteVirtualClusterResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/emr-containers.html#EMRContainers.Client.delete_virtual_cluster)
-        [Show boto3-stubs documentation](./client.md#delete-virtual-cluster)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/emr-containers.html#EMRContainers.Client.delete_virtual_cluster)
+        [Show boto3-stubs documentation](./client.md#delete_virtual_cluster)
         """
 
     def describe_job_run(self, id: str, virtualClusterId: str) -> DescribeJobRunResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/emr-containers.html#EMRContainers.Client.describe_job_run)
-        [Show boto3-stubs documentation](./client.md#describe-job-run)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/emr-containers.html#EMRContainers.Client.describe_job_run)
+        [Show boto3-stubs documentation](./client.md#describe_job_run)
         """
 
     def describe_managed_endpoint(
         self, id: str, virtualClusterId: str
     ) -> DescribeManagedEndpointResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/emr-containers.html#EMRContainers.Client.describe_managed_endpoint)
-        [Show boto3-stubs documentation](./client.md#describe-managed-endpoint)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/emr-containers.html#EMRContainers.Client.describe_managed_endpoint)
+        [Show boto3-stubs documentation](./client.md#describe_managed_endpoint)
         """
 
     def describe_virtual_cluster(self, id: str) -> DescribeVirtualClusterResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/emr-containers.html#EMRContainers.Client.describe_virtual_cluster)
-        [Show boto3-stubs documentation](./client.md#describe-virtual-cluster)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/emr-containers.html#EMRContainers.Client.describe_virtual_cluster)
+        [Show boto3-stubs documentation](./client.md#describe_virtual_cluster)
         """
 
     def generate_presigned_url(
@@ -160,8 +159,8 @@ class EMRContainersClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/emr-containers.html#EMRContainers.Client.generate_presigned_url)
-        [Show boto3-stubs documentation](./client.md#generate-presigned-url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/emr-containers.html#EMRContainers.Client.generate_presigned_url)
+        [Show boto3-stubs documentation](./client.md#generate_presigned_url)
         """
 
     def list_job_runs(
@@ -170,13 +169,13 @@ class EMRContainersClient:
         createdBefore: datetime = None,
         createdAfter: datetime = None,
         name: str = None,
-        states: List[JobRunState] = None,
+        states: List[JobRunStateType] = None,
         maxResults: int = None,
         nextToken: str = None,
     ) -> ListJobRunsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/emr-containers.html#EMRContainers.Client.list_job_runs)
-        [Show boto3-stubs documentation](./client.md#list-job-runs)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/emr-containers.html#EMRContainers.Client.list_job_runs)
+        [Show boto3-stubs documentation](./client.md#list_job_runs)
         """
 
     def list_managed_endpoints(
@@ -185,19 +184,19 @@ class EMRContainersClient:
         createdBefore: datetime = None,
         createdAfter: datetime = None,
         types: List[str] = None,
-        states: List[EndpointState] = None,
+        states: List[EndpointStateType] = None,
         maxResults: int = None,
         nextToken: str = None,
     ) -> ListManagedEndpointsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/emr-containers.html#EMRContainers.Client.list_managed_endpoints)
-        [Show boto3-stubs documentation](./client.md#list-managed-endpoints)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/emr-containers.html#EMRContainers.Client.list_managed_endpoints)
+        [Show boto3-stubs documentation](./client.md#list_managed_endpoints)
         """
 
     def list_tags_for_resource(self, resourceArn: str) -> ListTagsForResourceResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/emr-containers.html#EMRContainers.Client.list_tags_for_resource)
-        [Show boto3-stubs documentation](./client.md#list-tags-for-resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/emr-containers.html#EMRContainers.Client.list_tags_for_resource)
+        [Show boto3-stubs documentation](./client.md#list_tags_for_resource)
         """
 
     def list_virtual_clusters(
@@ -206,13 +205,13 @@ class EMRContainersClient:
         containerProviderType: Literal["EKS"] = None,
         createdAfter: datetime = None,
         createdBefore: datetime = None,
-        states: List[VirtualClusterState] = None,
+        states: List[VirtualClusterStateType] = None,
         maxResults: int = None,
         nextToken: str = None,
     ) -> ListVirtualClustersResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/emr-containers.html#EMRContainers.Client.list_virtual_clusters)
-        [Show boto3-stubs documentation](./client.md#list-virtual-clusters)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/emr-containers.html#EMRContainers.Client.list_virtual_clusters)
+        [Show boto3-stubs documentation](./client.md#list_virtual_clusters)
         """
 
     def start_job_run(
@@ -227,26 +226,26 @@ class EMRContainersClient:
         tags: Dict[str, str] = None,
     ) -> StartJobRunResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/emr-containers.html#EMRContainers.Client.start_job_run)
-        [Show boto3-stubs documentation](./client.md#start-job-run)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/emr-containers.html#EMRContainers.Client.start_job_run)
+        [Show boto3-stubs documentation](./client.md#start_job_run)
         """
 
     def tag_resource(self, resourceArn: str, tags: Dict[str, str]) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/emr-containers.html#EMRContainers.Client.tag_resource)
-        [Show boto3-stubs documentation](./client.md#tag-resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/emr-containers.html#EMRContainers.Client.tag_resource)
+        [Show boto3-stubs documentation](./client.md#tag_resource)
         """
 
     def untag_resource(self, resourceArn: str, tagKeys: List[str]) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/emr-containers.html#EMRContainers.Client.untag_resource)
-        [Show boto3-stubs documentation](./client.md#untag-resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/emr-containers.html#EMRContainers.Client.untag_resource)
+        [Show boto3-stubs documentation](./client.md#untag_resource)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_job_runs"]) -> ListJobRunsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/emr-containers.html#EMRContainers.Paginator.ListJobRuns)[Show boto3-stubs documentation](./paginators.md#listjobrunspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/emr-containers.html#EMRContainers.Paginator.ListJobRuns)[Show boto3-stubs documentation](./paginators.md#listjobrunspaginator)
         """
 
     @overload
@@ -254,7 +253,7 @@ class EMRContainersClient:
         self, operation_name: Literal["list_managed_endpoints"]
     ) -> ListManagedEndpointsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/emr-containers.html#EMRContainers.Paginator.ListManagedEndpoints)[Show boto3-stubs documentation](./paginators.md#listmanagedendpointspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/emr-containers.html#EMRContainers.Paginator.ListManagedEndpoints)[Show boto3-stubs documentation](./paginators.md#listmanagedendpointspaginator)
         """
 
     @overload
@@ -262,5 +261,5 @@ class EMRContainersClient:
         self, operation_name: Literal["list_virtual_clusters"]
     ) -> ListVirtualClustersPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/emr-containers.html#EMRContainers.Paginator.ListVirtualClusters)[Show boto3-stubs documentation](./paginators.md#listvirtualclusterspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/emr-containers.html#EMRContainers.Paginator.ListVirtualClusters)[Show boto3-stubs documentation](./paginators.md#listvirtualclusterspaginator)
         """
